@@ -9,8 +9,6 @@ use SVK::Editor::Sign;
 use SVK::Util qw( HAS_SVN_MIRROR get_buffer_from_editor slurp_fh find_svm_source tmpfile abs2rel );
 use SVN::Simple::Edit;
 
-my $target_prompt = '=== below are targets to be committed ===';
-
 sub options {
     ('m|message=s'  => 'message',
      'C|check-only' => 'check_only',
@@ -30,7 +28,13 @@ sub parse_arg {
 
 sub lock { $_[0]->lock_target ($_[1]) }
 
-sub target_prompt { $target_prompt }
+sub target_prompt {
+    loc('=== Targets to commit (you may delete items from it) ===');
+}
+
+sub message_prompt {
+    loc('=== Please enter your commit message above this line ===');
+}
 
 sub under_mirror {
     my ($self, $target) = @_;
@@ -70,7 +74,7 @@ sub get_commit_message {
     my ($self, $msg) = @_;
     return if defined $self->{message};
     $self->{message} = get_buffer_from_editor
-	(loc('log message'), $target_prompt, join ("\n", $msg || '', $target_prompt, ''), 'commit');
+	(loc('log message'), $self->message_prompt, join ("\n", $msg || '', $self->message_prompt, ''), 'commit');
 }
 
 # XXX: This should just return Editor::Dynamic objects
@@ -157,7 +161,7 @@ sub get_editor {
     if ($self->{patch}) {
 	require SVK::Patch;
 	die loc ("Illegal patch name: %1.\n", $self->{patch})
-	    if $self->{patch} !~ m/^[\w\-]+$/;
+	    if $self->{patch} =~ m!/!;
 	my $patch = SVK::Patch->new ($self->{patch}, $self->{xd},
 				     $target->depotname, $source, $target);
 	$patch->{ticket} = SVK::Merge->new (xd => $self->{xd})->merge_info ($source)->add_target ($source)->as_string
@@ -212,7 +216,7 @@ sub get_committable {
 	($fh, $file) = tmpfile ('commit', TEXT => 1, UNLINK => 0);
     }
 
-    print $fh "\n$target_prompt\n" if $fh;
+    print $fh "\n", $self->target_prompt, "\n" if $fh;
 
     my $targets = [];
     my $statuseditor = SVK::Editor::Status->new
@@ -253,7 +257,7 @@ sub get_committable {
         $target->{targets} ||= [];
 
 	($self->{message}, $targets) =
-	    get_buffer_from_editor (loc('log message'), $target_prompt,
+	    get_buffer_from_editor (loc('log message'), $self->target_prompt,
 				    undef, $file, $target->{copath}, $target->{targets});
 	unlink $file;
     }
