@@ -9,7 +9,7 @@ our @EXPORT_OK = qw(
 
     find_local_mirror find_svm_source resolve_svm_source traverse_history
 
-    read_file write_file slurp_fh md5_fh mimetype mimetype_is_text
+    read_file write_file slurp_fh md5_fh bsd_glob mimetype mimetype_is_text
 
     abs_path abs2rel catdir catfile catpath devnull dirname get_anchor 
     move_path make_path splitpath splitdir tmpdir tmpfile
@@ -36,16 +36,11 @@ list of functions to import.
 
 =cut
 
-use Config;
+use Config ();
 use SVK::I18N;
-use Digest::MD5;
-use Cwd;
-use File::Copy qw(move);
-use File::Path qw(mkpath);
-use File::Temp 0.14 qw(mktemp);
+use File::Glob qw(bsd_glob);
 use File::Basename qw(dirname);
 use File::Spec::Functions qw(catdir catpath splitpath splitdir tmpdir );
-use ExtUtils::MakeMaker ();
 # ra must be loaded earlier since it uses the default pool
 use SVN::Core;
 use SVN::Ra;
@@ -90,7 +85,7 @@ End of line marker: C<\015\012> on Win32, C<\012> otherwise.
 use constant IS_WIN32 => ($^O eq 'MSWin32');
 use constant TEXT_MODE => IS_WIN32 ? ':crlf' : '';
 use constant DEFAULT_EDITOR => IS_WIN32 ? 'notepad.exe' : 'vi';
-use constant HAS_SYMLINK => $Config{d_symlink};
+use constant HAS_SYMLINK => $Config::Config{d_symlink};
 
 sub HAS_SVN_MIRROR () {
     no warnings 'redefine';
@@ -152,16 +147,23 @@ sub get_buffer_from_editor {
     my $editor =	defined($ENV{SVN_EDITOR}) ? $ENV{SVN_EDITOR}
 	   		: defined($ENV{EDITOR}) ? $ENV{EDITOR}
 			: DEFAULT_EDITOR; # fall back to something
-    my @editor = split (' ', $editor);
+    my @editor = split (/ /, $editor);
     my $time = time;
 
     while (1) {
-        utime ($time - 10, $time - 10, $file);
-	my $mtime = (stat($file))[9];
+        open my $fh, '<', $file or die $!;
+        my $md5 = md5_fh($fh);
+        close $fh;
+
 	print loc("Waiting for editor...\n");
+
 	# XXX: check $?
-	system (@editor, $file) and die loc("Aborted: %1\n", $!);
-	last if (stat($file))[9] > $mtime;
+	system {$editor[0]} (@editor, $file) and die loc("Aborted: %1\n", $!);
+
+        open $fh, '<', $file or die $!;
+        last if ($md5 ne md5_fh($fh));
+        close $fh;
+
 	my $ans = get_prompt(
 	    loc("%1 not modified: a)bort, e)dit, c)ommit?", ucfirst($what)),
 	    qr/^[aec]/,
@@ -172,9 +174,13 @@ sub get_buffer_from_editor {
 
     open $fh, $file or die $!;
     local $/;
-    my @ret = defined $sep ? split (/\n\Q$sep\E\n/, <$fh>, 2) : (<$fh>);
+    my @ret = defined $sep ? split (/^\Q$sep\E$/m, <$fh>, 2) : (<$fh>);
     close $fh;
     unlink $file;
+
+    die loc("Cannot find separator; aborted.\n")
+        if defined($sep) and !defined($ret[1]);
+
     return $ret[0] unless wantarray;
 
     # Compare targets in commit message
@@ -323,8 +329,11 @@ Calculate MD5 checksum for data in the input filehandle.
 
 sub md5_fh {
     my $fh = shift;
+
+    require Digest::MD5;
     my $ctx = Digest::MD5->new;
     $ctx->addfile($fh);
+
     return $ctx->hexdigest;
 }
 
@@ -390,6 +399,7 @@ sub abs_path {
     my $path = shift;
 
     if (!IS_WIN32) {
+        require Cwd;
 	return Cwd::abs_path ($path) unless -l $path;
 	my (undef, $dir, $pathname) = splitpath ($path);
 	return catpath (undef, Cwd::abs_path ($dir), $pathname);
@@ -507,7 +517,9 @@ sub make_path {
     my $path = shift;
 
     return undef if !defined($path) or -d $path;
-    return mkpath([$path]);
+
+    require File::Path;
+    return File::Path::mkpath([$path]);
 }
 
 =head3 splitpath ($path)
@@ -541,7 +553,9 @@ sub tmpfile {
     my $dir = tmpdir;
     my $text = delete $args{TEXT};
     $temp = "svk-${temp}XXXXX";
-    return mktemp ("$dir/$temp") if exists $args{OPEN} && $args{OPEN} == 0;
+
+    require File::Temp;
+    return File::Temp::mktemp ("$dir/$temp") if exists $args{OPEN} && $args{OPEN} == 0;
     my $tmp = File::Temp->new ( TEMPLATE => $temp,
 				DIR => $dir,
 				SUFFIX => '.tmp',
@@ -570,6 +584,7 @@ Unlike C<is_symlink()>, the C<$filename> argument is not optional.
 =cut
 
 sub is_executable {
+    require ExtUtils::MakeMaker;
     defined($_[0]) and length($_[0]) and MM->maybe_command($_[0]);
 }
 
@@ -613,8 +628,9 @@ sub move_path {
     my ($source, $target) = @_;
 
     if (-d $source and (!-d $target or rmdir($target))) {
+        require File::Copy;
         make_path (dirname($target));
-        move ($source => $target) and return;
+        File::Copy::move ($source => $target) and return;
     }
 
     print loc(
